@@ -8,6 +8,7 @@ import traceback
 import threading
 import time
 from optparse import OptionParser
+from easycluster.server import server_check_runner, spawn_local
 
 rcode = '''\
 from __future__ import print_function
@@ -309,7 +310,7 @@ def parallel3():
 @define_test('Test spawnlocal')
 def testlocal():
     global l1
-    l1 = easycluster.spawn_local(svrclass=easycluster.QuietServer)
+    l1 = spawn_local(svrclass=easycluster.server.QuietServer)
     reftest()
     methods()
     attrs()
@@ -362,7 +363,7 @@ def disconnect_thread():
     time.sleep(0.2)
     t1.join()
 
-easycluster.server_check_runner()
+server_check_runner()
 
 options = OptionParser(usage='%prog [options] [host] [port]', description='Demo script for EasyCluster')
 easycluster.add_key_options(options)
